#!/usr/bin/env sh
# SPDX-License-Identifier: AGPL-3.0-or-later
# SPDX-FileCopyrightText: 2021-2024 JayVii <jayvii[AT]posteo[DOT]de>

# $1 - HTML Root
# $2 - prv/pub
# $3 - repo name
# $@ - optional list of refs, as given to post-update hook

# Error out if not all options are given
if [ -z "$3" ]; then
    echo "Usage:
git_export_tarball.sh \\
    \"/var/www/git.example.git\" \\
    \"pub\" \\
    \"stagit-jayvii.de\" \\
    \"refs/tags/v0.0.0\" # optional parameters given by post-update hook
    "
    exit 1;
fi

# Git-Repository
cd "${1}/${2}/${3}.git" || exit 1;

# Retrieve URL if set
if [ -f "${1}/url" ]; then
    URL=`cat ${1}/url`
fi

for REF in ${4}; do

    # fetch branches and tags from given ref
    BRANCHES="
        `git branch -a --contains $REF | awk '{ print $NF }'`
        `git tag --contains $REF | awk '{ print $NF }'`
    "

    # cycle through branches and tags
    for BRANCH in $BRANCHES; do

        # create archive
        git archive ${BRANCH} . \
            --format=tar.gz \
            -o "${BRANCH}.tar.gz"

        # create sha256 sum
        sha256sum "${BRANCH}.tar.gz" | \
            tee "${1}/${2}/${3}/exports/${BRANCH}.tar.gz.sha256" > /dev/null

        # move archive into exports folder
        mv "${BRANCH}.tar.gz" "${1}/${2}/${3}/exports/${BRANCH}.tar.gz"

        # Output for user
        echo "Archive can be retrieved from ${URL}/${2}/${3}/exports/${BRANCH}.tar.gz"

    done

done

